==> humhub-1.3.18.tar.gz: humhub-1.3.18/protected/humhub/messages/de/base.php <==
<?php
return array (
  '<strong>Confirm</strong> Action' => 'Aktion <strong>bestätigen</strong>',
  '<strong>Latest</strong> updates' => '<strong>Letzte</strong> Aktualisierungen',
  '<strong>Mail</strong> summary' => '<strong>E-Mail</strong> Zusammenfassung',
  'Account settings' => 'Kontoeinstellungen',
  'Add:' => 'Hinzufügen:',
  'Administration' => 'Administration',
  'Allow' => 'Erlauben',
  'An error occurred while handling your last action. (Handler not found).' => 'Während der letzten Aktion ist ein Fehler aufgetreten. (Handler not found)',
  'An unexpected error occurred while loading the search result.' => 'Während des Ladens der Suchergebnisse ist ein unerwarteter Fehler aufgetreten.',
  'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Ein unerwarteter Fehler ist aufgetreten. Sollte dieser weiterhin auftreten kontaktiere den Administrator.',
  'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Ein unerwarteter Serverfehler ist aufgetreten. Sollte dieser weiterhin auftreten kontaktiere den Administrator.',
  'An unknown error occurred while uploading.' => 'Während des Hochladens ist ein unbekannter Fehler aufgetreten.',
  'An unknown error occurred while uploading. Hint: check your upload_max_filesize and post_max_size php settings.' => 'Während des Hochladens ist ein unbekannter Fehler aufgetreten. Hinweis: Prüfe die PHP-Einstellungen "upload_max_filesize" und "post_max_size".',
  'Back' => 'Zurück',
  'Back to dashboard' => 'Zurück zur Übersicht',
  'Cancel' => 'Abbrechen',
  'Choose language:' => 'Sprache wählen:',
  'Close' => 'Schließen',
  'Collapse' => 'Einklappen',
  'Confirm' => 'Bestätigen',
  'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Die Quelle des Addons muss eine Instanz von HActiveRecordContent oder HActiveRecordContentAddon sein!',
  'Copy to clipboard' => 'In die Zwischenablage kopieren',
  'Could not find content of addon!' => 'Der Inhalt des Addons konnte nicht gefunden werden!',
  'Could not find requested page.' => 'Die angeforderte Seite kann nicht gefunden werden.',
  'Default' => 'Standard',
  'Delete' => 'Löschen',
  'Deny' => 'Ablehnen',
  'Do you really want to perform this action?' => 'Wollen Sie diese Aktion wirklich ausführen?',
  'Edit' => 'Bearbeiten',
  'Error' => 'Fehler',
  'Error while running your last action (Invalid request method).' => 'Fehler bei der Ausführung der letzten Aktion (Invalid request method).',
  'Error:' => 'Fehler:',
  'Expand' => 'Erweitern',
  'Export' => 'Exportieren',
  'Info:' => 'Info:',
  'Invalid request method!' => 'Ungültige Anfragemethode!',
  'It looks like you may have taken the wrong turn.' => 'Du hast womöglich den falschen Weg eingeschlagen.',
  'Language' => 'Sprache',
  'Loading...' => 'Lädt...',
  'Login' => 'Anmelden',
  'Logo of {appName}' => 'Logo von {appName}',
  'Logout' => 'Ausloggen',
  'Menu' => 'Menü',
  'Module is not enabled on this content container!' => 'Dieses Modul ist in diesem Content Container nicht aktiviert!',
  'My profile' => 'Mein Profil',
  'My profile image' => 'Mein Profilbild',
  'New profile image' => 'Neues Profilbild',
  'Next' => 'Weiter',
  'No error information given.' => 'Keine Fehlerbeschreibung verfügbar.',
  'Oooops...' => 'Uuuups...',
  'Open' => 'Öffnen',
  'Please type at least 3 characters' => 'Bitte mindestens 3 Zeichen eingeben',
  'Please type at least {count} characters' => 'Bitte wenigstens {count} Zeichen eingeben',
  'Powered by {name}' => 'Unterstützt von {name}',
  'Profile dropdown' => 'Profil Dropdown',
  'Profile image of {displayName}' => 'Profilbild von {displayName}',
  'Profile picture of {displayName}' => 'Profilbild von {displayName}',
  'Save' => 'Speichern',
  'Saved' => 'Gespeichert',
  'Search' => 'Suchen',
  'Select Me' => 'Mich auswählen',
  'Show less' => 'Weniger anzeigen',
  'Show more' => 'Mehr anzeigen',
  'Some files could not be uploaded:' => 'Einige Dateien konten nicht hochgeladen werden:',
  'Text could not be copied to clipboard' => 'Text konnte nicht in die Zwischenablage kopiert werden',
  'Text has been copied to clipboard' => 'Text wurde in die Zwischenablage kopiert',
  'The date has to be in the past.' => 'Datum muss in der Vergangenheit liegen.',
  'The file has been deleted.' => 'Die Datei wurde gelöscht.',
  'The requested resource could not be found.' => 'Die angeforderte Ressource konnte nicht gefunden werden.',
  'The space has been archived.' => 'Der Space wurde archiviert.',
  'The space has been unarchived.' => 'Der Space wurde dearchiviert.',
  'Time Zone' => 'Zeitzone',
  'Toggle comment menu' => 'Kommentarmenü umschalten',
  'Toggle panel menu' => 'Panelmenü umschalten',
  'Toggle post menu' => 'Beitragsmenü umschalten',
  'Toggle stream entry menu' => 'Streameintragsmenü umschalten',
  'Unsubscribe' => 'Abbestellen',
  'Upload' => 'Hochladen',
  'Upload file' => 'Datei hochladen',
  'You are not allowed to run this action.' => 'Du hast keine Berechtigung, diese Aktion auszuführen.',
);

==> humhub-1.4.2.tar.gz: humhub-1.4.2/protected/humhub/messages/de/base.php <==
<?php
return array (
  '<strong>Confirm</strong> Action' => 'Aktion <strong>bestätigen</strong>',
  '<strong>Latest</strong> updates' => '<strong>Letzte</strong> Aktualisierungen',
  '<strong>Mail</strong> summary' => '<strong>E-Mail</strong>-Zusammenfassung',
  'Account settings' => 'Einstellungen',
  'Add:' => 'Hinzufügen:',
  'Administration' => 'Administration',
  'Allow' => 'Erlauben',
  'An error occurred while handling your last action. (Handler not found).' => 'Während der letzten Aktion ist ein Fehler aufgetreten. (Handler not found)',
  'An unexpected error occurred while loading the search result.' => 'Während des Ladens der Suchergebnisse ist ein unerwarteter Fehler aufgetreten.',
  'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Ein unerwarteter Fehler ist aufgetreten. Sollte dieser weiterhin auftreten kontaktiere den Administrator.',
  'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Ein unerwarteter Serverfehler ist aufgetreten. Sollte dieser weiterhin auftreten kontaktiere den Administrator.',
  'An unknown error occurred while uploading.' => 'Während des Hochladens ist ein unbekannter Fehler aufgetreten.',
  'An unknown error occurred while uploading. Hint: check your upload_max_filesize and post_max_size php settings.' => 'Während des Hochladens ist ein unbekannter Fehler aufgetreten. Hinweis: Prüfe die PHP-Einstellungen "upload_max_filesize" und "post_max_size".',
  'Back' => 'Zurück',
  'Back to dashboard' => 'Zurück zur Übersicht',
  'Cancel' => 'Abbrechen',
  'Choose language:' => 'Sprache wählen:',
  'Close' => 'Schließen',
  'Collapse' => 'Einklappen',
  'Confirm' => 'Bestätigen',
  'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Die Quelle des Addons muss eine Instanz von HActiveRecordContent oder HActiveRecordContentAddon sein!',
  'Copy to clipboard' => 'In die Zwischenablage kopieren',
  'Could not find content of addon!' => 'Der Inhalt des Addons konnte nicht gefunden werden!',
  'Could not find requested page.' => 'Die angeforderte Seite kann nicht gefunden werden.',
  'Default' => 'Standard',
  'Delete' => 'Löschen',
  'Deny' => 'Ablehnen',
  'Do you really want to perform this action?' => 'Wollen Sie diese Aktion wirklich ausführen?',
  'Edit' => 'Bearbeiten',
  'Error' => 'Fehler',
  'Error while running your last action (Invalid request method).' => 'Fehler bei der Ausführung der letzten Aktion (Invalid request method).',
  'Error:' => 'Fehler:',
  'Expand' => 'Erweitern',
  'Export' => 'Exportieren',
  'Info:' => 'Info:',
  'Invalid request method!' => 'Ungültige Anfragemethode!',
  'It looks like you may have taken the wrong turn.' => 'Du hast womöglich den falschen Weg eingeschlagen.',
  'Language' => 'Sprache',
  'Loading...' => 'Lädt ...',
  'Login' => 'Anmelden',
  'Logo of {appName}' => 'Logo von {appName}',
  'Logout' => 'Ausloggen',
  'Menu' => 'Menü',
  'Module is not enabled on this content container!' => 'Dieses Modul ist in diesem Content Container nicht aktiviert!',
  'My profile' => 'Mein Profil',
  'My profile image' => 'Mein Profilbild',
  'New profile image' => 'Neues Profilbild',
  'Next' => 'Weiter',
  'No error information given.' => 'Keine Fehlerbeschreibung verfügbar.',
  'Oooops...' => 'Uuuups...',
  'Open' => 'Öffnen',
  'Please type at least 3 characters' => 'Bitte mindestens 3 Zeichen eingeben',
  'Please type at least {count} characters' => 'Bitte wenigstens {count} Zeichen eingeben',
  'Powered by {name}' => 'Unterstützt von {name}',
  'Profile dropdown' => 'Profil Dropdown',
  'Profile image of {displayName}' => 'Profilbild von {displayName}',
  'Profile picture of {displayName}' => 'Profilbild von {displayName}',
  'Save' => 'Speichern',
  'Saved' => 'Gespeichert',
  'Search' => 'Suchen',
  'Select Me' => 'Mich auswählen',
  'Show less' => 'Weniger anzeigen',
  'Show more' => 'Mehr anzeigen',
  'Some files could not be uploaded:' => 'Einige Dateien konten nicht hochgeladen werden:',
  'Text could not be copied to clipboard' => 'Text konnte nicht in die Zwischenablage kopiert werden',
  'Text has been copied to clipboard' => 'Text wurde in die Zwischenablage kopiert',
  'The date has to be in the past.' => 'Datum muss in der Vergangenheit liegen.',
  'The file has been deleted.' => 'Die Datei wurde gelöscht.',
  'The requested resource could not be found.' => 'Die angeforderte Ressource konnte nicht gefunden werden.',
  'The space has been archived.' => 'Der Space wurde archiviert.',
  'The space has been unarchived.' => 'Der Space wurde dearchiviert.',
  'Time Zone' => 'Zeitzone',
  'Toggle comment menu' => 'Kommentarmenü umschalten',
  'Toggle panel menu' => 'Panelmenü umschalten',
  'Toggle post menu' => 'Beitragsmenü umschalten',
  'Toggle stream entry menu' => 'Streameintragsmenü umschalten',
  'Unsubscribe' => 'Abbestellen',
  'Upload' => 'Hochladen',
  'Upload file' => 'Datei hochladen',
  'You are not allowed to run this action.' => 'Du hast keine Berechtigung, diese Aktion auszuführen.',
);
